@@ -1,6 +1,6 @@
 
 from .clientBase import MqClientExceptionClass, MqClientProcessLoopTimeoutExceptionClass, MqClientThreadHealthCheckExceptionClass
-from .main import createObjectStoreInstance
+from .main import createMQClientInstance
 
 from ._version import get_versions
 __version__ = get_versions()['version']
